package fragment;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import com.akamai.captioning.CaptionComponent;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

public class WebVTTFragment extends android.support.v4.app.Fragment implements View.OnTouchListener, IPlayerEventsListener {

    private VideoPlayerContainer mVideoContainer;

    private VideoPlayerView mVideoView;

    private ProgressBar mProgressBar;

    private Boolean mWasPlaying = false;

    private int mCurrentPosition = 0;

    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/april11/hdworld/hdworld_,512x288_450_b,640x360_700_b,768x432_1000_b,1024x576_1400_m,1280x720_1900_m,1280x720_2500_m,1280x720_3500_m,.mp4.csmil/master.m3u8";

    // Captioning plugin
    private CaptionComponent mCaptionComponent;

    // Captioning variables
    private final String CAPTION_ASSET_URL = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/sample.vtt";

    public static WebVTTFragment newInstance() {
        WebVTTFragment fragment = new WebVTTFragment();
        return fragment;
    }

    public WebVTTFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {

        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        // Initialize the progress bar with the xml
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);

        // Set the decoding mode used by the Android SDK video control
        mVideoContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);

        // Get a reference to the VideoView object
        mVideoView = mVideoContainer.getVideoPlayer();

        // Set the progress to the player
        mVideoView.setProgressBarControl(mProgressBar);

        // Set your license
        mVideoView.setLicense(MainActivity.LICENSE);

        // Set the screen mode
        mVideoView.setFullScreen(true);
        mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

        // Activate the logs
        mVideoView.setLogEnabled(true);

        // Get a reference to the Caption Component object
        mCaptionComponent = (CaptionComponent) rootView.findViewById(R.id.captionView);

        //Generate captions after configure the AMP player
        createCaptions();

        mVideoView.setEventsListener(this);
        ((View)mVideoView).setKeepScreenOn(true);
        ((View)mVideoView).setOnTouchListener(this);

        // Play the stream
        mVideoView.playUrl(VIDEO_URL);
        return rootView;
    }

    /**
     * Caption configuration
     */
    private void createCaptions(){
        mCaptionComponent.setVideoPlayerView(mVideoView);
        mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTIONS_TEXT_DROP_SHADOW_STYLE);
        mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_TOP);
        mCaptionComponent.setTextSize(22);
        mCaptionComponent.setTextBackgroundColor(Color.BLACK);
        mCaptionComponent.setTextColor(Color.YELLOW);
        mCaptionComponent.setTextWindowColor(Color.GREEN);
        mCaptionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_POP_ON);

        // External VTT file, for media assets with no integrated captions
        mCaptionComponent.loadExternalVTTResource("English", "en", CAPTION_ASSET_URL);
    }

    @Override
    public void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.playUrl(VIDEO_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d("PlayerView", "OnPause");
        if (mVideoView.isPlaying() || mVideoView.isPaused()) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
        }
        mVideoView.stop();
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        switch(iInEventType) {
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_LOADING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FINISHED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_ERROR:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_POSITION_UPDATE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_END_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH_REQUESTED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FULLSCREEN_MODE_CHANGE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SIZE_CHANGE:
                break;

            default:
                break;
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }
}